@@ -5,10 +5,13 @@
 """CLI program."""
 
 import importlib.metadata
-from pathlib import Path
+from typing import TYPE_CHECKING
 
-from wurzel.step import TypedStep
-from wurzel.step_executor import BaseStepExecutor
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from wurzel.step import TypedStep
+    from wurzel.step_executor import BaseStepExecutor
 
 __all__ = ["generate_cli_call"]
 try:
@@ -20,10 +23,10 @@ __version_info__ = __version__.split(".")
 
 
 def generate_cli_call(
-    step_cls: type[TypedStep],
-    inputs: list[Path],
-    output: Path,
-    executor: type[BaseStepExecutor] = None,
+    step_cls: "type[TypedStep]",
+    inputs: "list[Path]",
+    output: "Path",
+    executor: "type[BaseStepExecutor] | None" = None,
     encapsulate_env: bool = True,
 ) -> str:
     """Generate the cli call to execute a given step with its
@@ -39,9 +42,9 @@ def generate_cli_call(
 
     """
     if inputs:
-        inputs = "-i " + " -i ".join(str(i) for i in inputs)
+        inputs_str = "-i " + " -i ".join(str(i) for i in inputs)
     else:
-        inputs = ""
+        inputs_str = ""
     return " ".join(
         [
             "wurzel run",
@@ -49,7 +52,7 @@ def generate_cli_call(
             "-o",
             str(output.absolute()),
             "" if executor is None else f"-e {executor.__qualname__}",
-            inputs,
+            inputs_str,
             "--encapsulate-env" if encapsulate_env else "--no-encapsulate-env",
         ]
     )
